@@ -28,7 +28,7 @@ def create_job_span(task_instance, job_uid, inputs, outputs, metadata, context_j
         job = CreateJob(
             uid=job_uid,
             name=f'{job_uid} Job',
-            version=pipeline_run.versionId,
+            pipeline_run_id=pipeline_run.id,
             description=f'{job_uid} created using torch job decorator',
             inputs=inputs,
             outputs=outputs,
